//@line 36 "/buildbot/linux_repack/build/releases/l10n-mozilla-1.9.1/sl/mail/all-l10n.js"

//@line 38 "/buildbot/linux_repack/build/releases/l10n-mozilla-1.9.1/sl/mail/all-l10n.js"

pref("general.useragent.locale", "sl");
pref("spellchecker.dictionary", "sl");
